import json

import requests

from e2enetworks.cloud.aiplatform import config
from e2enetworks.cloud.aiplatform.constants import BASE_GPU_URL, BUCKET_TYPES, BUCKET_TYPES_HELP
from e2enetworks.cloud.aiplatform.decorators.validate_access_key_and_token import validate_access_key_and_token
from e2enetworks.cloud.aiplatform.constants import headers


class Datasets:
    def __init__(self, team_id, project_id):
        self.team_id = team_id
        self.project_id = project_id
        self.validate()

    def validate(self):
        if type(self.team_id) != int:
            print(f"Team Id -{self.team_id} Should be Integer")
            return False, f"Team Id -{self.team_id}should be Integer"
        if type(self.project_id) != int:
            print(f"Project Id -{self.project_id} Should be Integer")
            return False, f"Project Id -{self.project_id} should be Integer"
        return True, "Success"

    def clear_values(self):
        self.team_id = None
        self.project_id = None

    def create(self, name=None, bucket_name=None, bucket_type=None, description=""):

        if bucket_type not in BUCKET_TYPES:
            print(f"Bucket Type Should be in {BUCKET_TYPES}")
            print(BUCKET_TYPES_HELP)
            return f"Bucket Type Should ne in {BUCKET_TYPES}"

        data = {
            "type": bucket_type,
            "name": name,
            "bucket_name": bucket_name,
            "description": description,
        }
        payload = json.dumps(data)
        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/datasets/?apikey={config.apikey}"
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("POST", url, headers=headers, data=payload)

        return response

    def get(self, dataset_id):
        status, response = self.validate()

        if not status:
            return response

        if type(dataset_id) != int:
            print(f"Dataset ID - {dataset_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/datasets/{dataset_id}/" \
              f"?apikey={config.apikey}"

        headers['Authorization'] = f'Bearer {config.auth_token}'
        payload = ""

        response = requests.request("GET", url, headers=headers, data=payload)

        return response

    @validate_access_key_and_token
    def list(self):

        status, response = self.validate()

        if not status:
            return response

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/datasets/?apikey={config.apikey}"

        headers['Authorization'] = f'Bearer {config.auth_token}'
        payload = ""

        response = requests.request("GET", url, headers=headers, data=payload)

        return response

    def delete(self, dataset_id):
        status, response = self.validate()

        if not status:
            return response

        if type(dataset_id) != int:
            print(f"Dataset ID - {dataset_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/datasets/{dataset_id}/" \
              f"?apikey={config.apikey}"

        headers['Authorization'] = f'Bearer {config.auth_token}'
        payload = ""

        response = requests.request("DELETE", url, headers=headers, data=payload)

        return response

    @staticmethod
    def help():
        print("Datasets Class Help")
        print("\t\t=================")
        print("\t\tThis class provides functionalities to interact with Datasets.")
        print("\t\tAvailable methods:")
        print(
            "\t\t1. __init__(team_id, project_id): Initializes a Datasets instance with the specified team and "
            "project IDs.")
        print(f"\t\t2. create(name, bucket_name=, bucket_type, description): Creates a new dataset with the provided"
              f"name, bucket name, bucket type and description\n Bucket Name is not required in case of"
              f" bucket_type='managed'")
        print("\t\t3. get(bucket_name): Retrieves information about a specific dataset using its bucket name.")
        print("\t\t4. list(): Lists all datasets associated with the team and project.")
        print("\t\t5. delete(bucket_name): Deletes a dataset with the given bucket name.")
        print("\t\t6. clear_values(): Resets the team and project IDs to None.")
        print("\t\t7. validate(): Checks if the team and project IDs are of integer type.")
        print("\t\t8. help(): Displays this help message.")

        # Example usages
        print("\t\tExample usages:")
        print("\t\tdatasets = Datasets(123, 456)")
        print(f"\t\tdatasets.create(name='Test Dataset', bucket_name='dataset-bucket', bucket_type={BUCKET_TYPES},"
              f" description='Test Dataset')")
        print("\t\tdatasets.get('Bucket Name')")
        print("\t\tdatasets.list()")
        print("\t\tdatasets.delete('Bucket Name')")



import json

import requests

from e2enetworks.cloud.aiplatform import config
from e2enetworks.cloud.aiplatform.constants import (BASE_GPU_URL, STATUS_CODE,
                                                    VALIDATED_SUCCESSFULLY, INVALID_CREDENTIALS)


class init:
    def __init__(self, auth_token, apikey):
        config.apikey = apikey
        config.auth_token = auth_token
        self.validate(auth_token, apikey)

    def validate(self, auth_token, apikey):
        url = f"{BASE_GPU_URL}customer/details/?apikey={apikey}"
        payload = ""
        headers = {
            'Authorization': f'Bearer {auth_token}'
        }
        response = requests.request("GET", url, headers=headers, data=payload)
        if response.status_code == STATUS_CODE:
            print(VALIDATED_SUCCESSFULLY)
        else:
            print(INVALID_CREDENTIALS)
            self.clear_values()

    def clear_values(self):
        config.apikey = None
        config.auth_token = None

    @staticmethod
    def help():
        print("Init Class Help")
        print("\t\t=================")
        print("\t\tThis class provides functionalities for initialization.")
        print("\t\tAvailable methods:")
        print("\t\t1. __init__(auth_token, apikey): Initializes an Init instance with the provided authentication"
              " token and API key.")
        print("\t\t2. validate(auth_token, apikey): Validates the provided authentication token and API key.")
        print("\t\t3. clear_values(): Resets the API key and authentication token to None.")
        print("\t\t4. help(): Displays this help message.")

        # Example usage
        print("\t\t\nExample usage:")
        print("\t\tinit = init('Auth Token', 'API Key')")



import json

import requests

from e2enetworks.cloud.aiplatform import config
from e2enetworks.cloud.aiplatform.constants import BASE_GPU_URL, INDENTATION
from e2enetworks.cloud.aiplatform.decorators.validate_access_key_and_token import validate_access_key_and_token
from e2enetworks.cloud.aiplatform.constants import headers


class EndPoints:
    def __init__(self, team_id, project_id):
        self.team_id = team_id
        self.project_id = project_id
        self.validate()

    def validate(self):
        if type(self.team_id) != int:
            print(f"Team Id -{self.team_id} Should be Integer")
            return False, f"Team Id -{self.team_id}should be Integer"
        if type(self.project_id) != int:
            print(f"Project Id -{self.project_id} Should be Integer")
            return False, f"Project Id -{self.project_id} should be Integer"
        return True, "Success"

    def clear_values(self):
        self.team_id = None
        self.project_id = None

    @validate_access_key_and_token
    def create(self, name, sku_id, prefix, replica, model_id):

        status, response = self.validate()

        if not status:
            return response

        payload = json.dumps({
            "name": name,
            "sku_id": sku_id,
            "prefix": prefix,
            "replica": replica,
            "model_id": model_id
        })

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/serving/inference/" \
              f"?apikey={config.apikey}"
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("POST", url, headers=headers, data=payload)

        

    @validate_access_key_and_token
    def get(self, endpoint_id):

        status, response = self.validate()

        if not status:
            return response

        if type(endpoint_id) != int:
            print(f"EndPoint ID - {endpoint_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/serving/inference/{endpoint_id}/?" \
              f"apikey={config.apikey}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        
        return response

    @validate_access_key_and_token
    def list(self):

        status, response = self.validate()

        if not status:
            return response

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/serving/inference/" \
              f"?apikey={config.apikey}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        
        return response

    @validate_access_key_and_token
    def delete(self, endpoint_id):

        status, response = self.validate()

        if not status:
            return response

        if type(endpoint_id) != int:
            print(f"EndPoint ID - {endpoint_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/serving/inference/{endpoint_id}/" \
              f"?apikey={config.apikey}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("DELETE", url, headers=headers, data=payload)
        
        return response

    @staticmethod
    def help():
        print("EndPoint Class Help")
        print("\t\t=================")
        print("\t\tThis class provides functionalities to interact with EndPoint.")
        print("\t\tAvailable methods:")
        print("\t\t1. __init__(team_id, project_id): Initializes an EndPoints instance with the specified team and "
              "project IDs.")
        print("\t\t2. create(name, sku_id, prefix, replica, model_id): Creates an endpoint with the provided details.")
        print("\t\t3. get(endpoint_id): Retrieves information about a specific endpoint using its ID.")
        print("\t\t4. list(): Lists all endpoints associated with the team and project.")
        print("\t\t5. delete(endpoint_id): Deletes an endpoint with the given ID.")
        print("\t\t6. clear_values(): Resets the team and project IDs to None.")
        print("\t\t7. validate(): Checks if the team and project IDs are of integer type.")
        print("\t\t8. help(): Displays this help message.")

        # Example usages
        print("\t\tExample usages:")
        print("\t\tendpoints = EndPoints(123, 456)")
        print("\t\tendpoints.create('Name', sku_id, 'Prefix', replica, model_id)")
        print("\t\tendpoints.get(789)")
        print("\t\tendpoints.list()")
        print("\t\tendpoints.delete(789)")



import json

import requests

from e2enetworks.cloud.aiplatform import config
from e2enetworks.cloud.aiplatform.constants import BASE_GPU_URL, INDENTATION
from e2enetworks.cloud.aiplatform.decorators.validate_access_key_and_token import validate_access_key_and_token
from e2enetworks.cloud.aiplatform.constants import headers


class Projects:
    def __init__(self, team_id):
        self.team_id = team_id
        self.validate()

    def validate(self):
        if type(self.team_id) != int:
            print(f"Team Id -{self.team_id} Should be Integer")
            return False, f"Team Id -{self.team_id}should be Integer"
        return True, "Success"

    def clear_values(self):
        self.team_id = None

    @validate_access_key_and_token
    def create(self, project_name):

        status, response = self.validate()

        if not status:
            return response

        payload = json.dumps({
            "project_name": project_name,
        })

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/?apikey={config.apikey}"
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("POST", url, headers=headers, data=payload)

        return response

    @validate_access_key_and_token
    def get(self, project_id):

        status, response = self.validate()

        if not status:
            return response

        if type(project_id) != int:
            print(f"Project ID - {project_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{project_id}/?apikey={config.apikey}"
        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        
        return response

    @validate_access_key_and_token
    def list(self):
        status, response = self.validate()

        if not status:
            return response

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/?apikey={config.apikey}"
        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        
        return response

    @validate_access_key_and_token
    def delete(self, project_id):

        status, response = self.validate()

        if not status:
            return response

        if type(project_id) != int:
            print(f"Project ID - {project_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{project_id}/?apikey={config.apikey}"
        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("DELETE", url, headers=headers, data=payload)
        
        return response

    @staticmethod
    def help():
        print("Projects Class Help")
        print("\t\t===================")
        print("\t\tThis class provides functionalities to interact with projects.")
        print("\t\tAvailable methods:")
        print("\t\t1. __init__(team_id): Initializes a Projects instance with the specified team ID.")
        print("\t\t2. create(project_name): Creates a new project with the provided project name.")
        print("\t\t3. get(project_id): Retrieves information about a specific project using its ID.")
        print("\t\t4. list(): Lists all projects associated with the team.")
        print("\t\t5. delete(project_id): Deletes a project with the given ID.")
        print("\t\t6. clear_values(): Resets the team ID to None.")
        print("\t\t7. validate(): Checks if the team ID is of integer type.")
        print("\t\t8. help(): Displays this help message.")

        # Example usages
        print("\t\tExample usages:")
        print("\t\tprojects = Projects(123)")
        print("\t\tprojects.create('Project Name')")
        print("\t\tprojects.get(456)")
        print("\t\tprojects.list()")
        print("\t\tprojects.delete(456)")



import json

import requests

from e2enetworks.cloud.aiplatform import config
from e2enetworks.cloud.aiplatform.constants import BASE_GPU_URL, INDENTATION
from e2enetworks.cloud.aiplatform.decorators.validate_access_key_and_token import validate_access_key_and_token
from e2enetworks.cloud.aiplatform.constants import headers


class Teams:
    @validate_access_key_and_token
    def create(self, team_name):
        payload = json.dumps({
            "team_name": team_name,
        })
        url = f"{BASE_GPU_URL}teams/?apikey={config.apikey}"

        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("POST", url, headers=headers, data=payload)

        
        return response

    @validate_access_key_and_token
    def get(self, team_id):

        if type(team_id) != int:
            print(f"Team ID - {team_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{team_id}/?apikey={config.apikey}"

        payload = ""

        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        
        return response

    @validate_access_key_and_token
    def list(self):
        url = f"{BASE_GPU_URL}teams/?apikey={config.apikey}"
        payload = ""

        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        return response

    @validate_access_key_and_token
    def delete(self, team_id):

        if type(team_id) != int:
            print(f"Team ID - {team_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{team_id}/?apikey={config.apikey}"
        payload = ""

        headers['Authorization'] = f'Bearer {config.auth_token}'
        response = requests.request("DELETE", url, headers=headers, data=payload)
        
        return response

    @staticmethod
    def help():
        print("Teams Class Help")
        print("\t\t================")
        print("\t\tThis class provides functionalities to interact with teams.")
        print("\t\tAvailable methods:")
        print("\t\t1. create(team_name): Creates a new team with the provided team name.")
        print("\t\t2. get(team_id): Retrieves information about a specific team using its ID.")
        print("\t\t3. list(): Lists all teams.")
        print("\t\t4. delete(team_id): Deletes a team with the given ID.")
        print("\t\t5. help(): Displays this help message.")

        # Example usages
        print("\t\tExample usages:")
        print("\t\tteams = Teams()")
        print("\t\tteams.create('Team Name')")
        print("\t\tteams.get(123)")
        print("\t\tteams.list()")
        print("\t\tteams.delete(123)")



from e2enetworks.cloud.aiplatform import config


def validate_access_key_and_token(func):
    def inner1(*args, **kwargs):
        if not config.apikey:
            return f"APIKEY = {config.apikey} is not Valid"
        if not config.auth_token:
            return f"AUTH-TOKEN = {config.auth_token} is not Valid"
        return func(*args, **kwargs)
    return inner1



import json

import requests

from e2enetworks.cloud.aiplatform import config
from e2enetworks.cloud.aiplatform.constants import BASE_GPU_URL, INDENTATION
from e2enetworks.cloud.aiplatform.decorators.validate_access_key_and_token import validate_access_key_and_token
from e2enetworks.cloud.aiplatform.constants import headers


class APITokens:
    def __init__(self, team_id, project_id):
        self.team_id = team_id
        self.project_id = project_id
        self.validate()

    def validate(self):
        if type(self.team_id) != int:
            print(f"Team Id -{self.team_id} Should be Integer")
            return False, f"Team Id -{self.team_id}should be Integer"
        if type(self.project_id) != int:
            print(f"Project Id -{self.project_id} Should be Integer")
            return False, f"Project Id -{self.project_id} should be Integer"
        return True, "Success"

    def clear_values(self):
        self.team_id = None
        self.project_id = None

    @validate_access_key_and_token
    def create(self, auth_token):

        status, response = self.validate()

        if not status:
            return response

        payload = json.dumps({
            "auth_token": auth_token,
        })

        headers['Authorization'] = f'Bearer {config.auth_token}'

        url = f"{BASE_GPU_URL}teams/{self.team_id}/auth-token/?apikey={config.apikey}&project_id={self.project_id}"

        response = requests.request("POST", url, headers=headers, data=payload)

        

    @validate_access_key_and_token
    def list(self):

        status, response = self.validate()

        if not status:
            return response

        url = f"{BASE_GPU_URL}teams/{self.team_id}/auth-token/?apikey={config.apikey}&project_id={self.project_id}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        

    @validate_access_key_and_token
    def delete(self, token_id):

        status, response = self.validate()

        if not status:
            return response

        if type(token_id) != int:
            print(f"Token ID - {token_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/auth-token/{token_id}/?apikey={config.apikey}&project_id=" \
              f"{self.project_id}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("DELETE", url, headers=headers, data=payload)
        return response

    @staticmethod
    def help():
        print("APITokens Class Help")
        print("\t\t====================")
        print("\t\tThis class provides functionalities to manage API tokens.")
        print("\t\tAvailable methods:")
        print(
            "\t\t1. __init__(team_id, project_id): Initializes an APITokens instance with the specified team ID and "
            "project ID.")
        print("\t\t2. create(auth_token): Creates a new API token with the provided authentication token.")
        print("\t\t3. list(): Lists all API tokens associated with the team and project.")
        print("\t\t4. delete(token_id): Deletes an API token with the given token ID.")
        print("\t\t5. clear_values(): Resets the team ID and project ID to None.")
        print("\t\t6. validate(): Checks if the team ID and project ID are of integer type.")
        print("\t\t7. help(): Displays this help message.")

        # Example usages
        print("\t\tExample usages:")
        print("\t\tapi_tokens = APITokens(123, 456)")
        print("\t\tapi_tokens.create('auth_token')")
        print("\t\tapi_tokens.list()")
        print("\t\tapi_tokens.delete(789)")


import requests

from e2enetworks.cloud.aiplatform import config
from e2enetworks.cloud.aiplatform.constants import BASE_GPU_URL
from e2enetworks.cloud.aiplatform.decorators.validate_access_key_and_token import validate_access_key_and_token
from e2enetworks.cloud.aiplatform.constants import headers


class Skus:

    @validate_access_key_and_token
    def list(self, image_id, service):

        if type(image_id) != int:
            print(f"Image ID - {image_id} Should be Integer")
            return

        if type(service) != str:
            print(f"Service - {service} Should be String")
            return

        url = f"{BASE_GPU_URL}gpu_service/sku/?apikey={config.apikey}&image_id={image_id}&service={service}"
        payload = ""

        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        return response

    @staticmethod
    def help():
        print("Sku Class Help")
        print("\t\t================")
        print("\t\tThis class provides functionalities to interact with Skus.")
        print("\t\tAvailable methods:")

        print("\t\t1. list(image_id, service): Lists all Skus for given image_id and service.")
        print("\t\t Allowed Services List - ['notebook', 'inference']")
        # Example usages
        print("\t\tExample usages:")
        print("\t\tskus = Skus()")
        print("\t\tskus.list(image_id, service)")



import json

import requests

from e2enetworks.cloud.aiplatform import config
from e2enetworks.cloud.aiplatform.constants import BASE_GPU_URL, INDENTATION
from e2enetworks.cloud.aiplatform.decorators.validate_access_key_and_token import validate_access_key_and_token
from e2enetworks.cloud.aiplatform.constants import headers


class Notebooks:
    def __init__(self, team_id, project_id):
        self.team_id = team_id
        self.project_id = project_id
        self.validate()

    def validate(self):
        if type(self.team_id) != int:
            print(f"Team Id -{self.team_id} Should be Integer")
            return False, f"Team Id -{self.team_id}should be Integer"
        if type(self.project_id) != int:
            print(f"Project Id -{self.project_id} Should be Integer")
            return False, f"Project Id -{self.project_id} should be Integer"
        return True, "Success"

    def clear_values(self):
        self.team_id = None
        self.project_id = None

    @validate_access_key_and_token
    def create(self, name, sku_id, image_id, instance_type):
        status, response = self.validate()

        if not status:
            return response

        payload = json.dumps({
            "name": name,
            "image_id": image_id,
            "sku_id": sku_id,
            "instance_type": instance_type
        })
        headers['Authorization'] = f'Bearer {config.auth_token}'
        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/notebooks/" \
              f"?apikey={config.apikey}"

        return requests.request("POST", url, headers=headers, data=payload)

    @validate_access_key_and_token
    def get(self, notebook_id):

        status, response = self.validate()

        if not status:
            return response

        if type(notebook_id) != int:
            print(f"Notebook ID - {notebook_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/notebooks/{notebook_id}/?" \
              f"apikey={config.apikey}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        
        return response

    @validate_access_key_and_token
    def list(self):

        status, response = self.validate()

        if not status:
            return response

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/notebooks/" \
              f"?apikey={config.apikey}"
        payload = ""
        response = requests.request("GET", url, headers=headers, data=payload)
        
        return response

    @validate_access_key_and_token
    def delete(self, notebook_id):

        status, response = self.validate()

        if not status:
            return response

        if type(notebook_id) != int:
            print(f"Notebook ID - {notebook_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/notebooks/{notebook_id}/?" \
              f"apikey={config.apikey}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("DELETE", url, headers=headers, data=payload)
        
        return response

    @validate_access_key_and_token
    def stop(self, notebook_id):

        status, response = self.validate()

        if not status:
            return response

        if type(notebook_id) != int:
            print(f"Notebook ID - {notebook_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/notebooks/{notebook_id}/actions/" \
              f"?action=stop&apikey={config.apikey}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("PUT", url, headers=headers, data=payload)
        
        return response

    @validate_access_key_and_token
    def start(self, notebook_id):

        status, response = self.validate()

        if not status:
            return response

        if type(notebook_id) != int:
            print(f"Notebook ID - {notebook_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/notebooks/{notebook_id}/actions/" \
              f"?action=start&apikey={config.apikey}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("PUT", url, headers=headers, data=payload)
        
        return response

    def upgrade(self, notebook_id, size):
        status, response = self.validate()

        if not status:
            return response

        if type(notebook_id) != int:
            print(f"Notebook ID - {notebook_id} Should be Integer")
            return

        if type(size) != int:
            print(f"Size - {size} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/notebooks/{notebook_id}/pvc/" \
              f"upgrade/?apikey={config.apikey}"

        payload = json.dumps({
            "size": size
        })
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("PUT", url, headers=headers, data=payload)
        
        return response

    @staticmethod
    def help():
        print("\t\tNotebook Class Help")
        print("\t\t=================")
        help_text = """
                Notebooks class provides methods to interact with notebooks in a project.

                Available methods:
                1. create(name, sku_id, image_id, instance_type): Create a new notebook.
                2. get(notebook_id): Get information about a notebook.
                3. list(): List all notebooks in the project.
                4. delete(notebook_id): Delete a notebook.
                5. stop(notebook_id): Stop a running notebook.
                6. start(notebook_id): Start a stopped notebook.
                7. upgrade(notebook_id, size): Upgrade the size of a notebook's PVC.

                Usage:
                notebooks = Notebooks(team_id, project_id)
                notebooks.create(name, sku_id, image_id, instance_type)
                notebooks.get(notebook_id)
                notebooks.list()
                notebooks.delete(notebook_id)
                notebooks.stop(notebook_id)
                notebooks.start(notebook_id)
                notebooks.upgrade(notebook_id, size)
                """
        print(help_text)



import json

import requests

from e2enetworks.cloud.aiplatform import config
from e2enetworks.cloud.aiplatform.constants import BASE_GPU_URL, INDENTATION
from e2enetworks.cloud.aiplatform.decorators.validate_access_key_and_token import validate_access_key_and_token
from e2enetworks.cloud.aiplatform.constants import headers


class Models:
    def __init__(self, team_id, project_id):
        self.team_id = team_id
        self.project_id = project_id
        self.validate()

    def validate(self):
        if type(self.team_id) != int:
            print(f"Team Id -{self.team_id} Should be Integer")
            return False, f"Team Id -{self.team_id}should be Integer"
        if type(self.project_id) != int:
            print(f"Project Id -{self.project_id} Should be Integer")
            return False, f"Project Id -{self.project_id} should be Integer"
        return True, "Success"

    def clear_values(self):
        self.team_id = None
        self.project_id = None

    @validate_access_key_and_token
    def create(self, name, bucket_type, bucket_name, model_type):

        status, response = self.validate()

        if not status:
            return response

        payload = json.dumps({
            "name": name,
            "type": bucket_type,
            "bucket_name": bucket_name,
            "model_type": model_type
        })

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/serving/model/" \
              f"?apikey={config.apikey}"
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("POST", url, headers=headers, data=payload)

        
        return response

    @validate_access_key_and_token
    def get(self, model_id):

        status, response = self.validate()

        if not status:
            return response

        if type(model_id) != int:
            print(f"Model ID - {model_id} Should be Integer")
            return

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/serving/model/{model_id}" \
              f"?apikey={config.apikey}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        
        return response

    @validate_access_key_and_token
    def list(self):

        status, response = self.validate()

        if not status:
            return response

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/serving/model/" \
              f"?apikey={config.apikey}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        
        return response

    @validate_access_key_and_token
    def delete(self, model_id):
        status, response = self.validate()

        if not status:
            return response

        if type(model_id) != int:
            return f"Model ID - {model_id} Should be Integer"

        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/serving/model/{model_id}/" \
              f"?apikey={config.apikey}"

        payload = ""
        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("DELETE", url, headers=headers, data=payload)
        
        return response

    @staticmethod
    def help():
        print("Models Class Help")
        print("\t\t=================")
        print("\t\tThis class provides functionalities to interact with models.")
        print("\t\tAvailable methods:")
        print(
            "\t\t1. __init__(team_id, project_id): Initializes a Models instance with the specified team and project "
            "IDs.")
        print("\t\t2. create(name, bucket_type, bucket_name, model_type): Creates a new model with the provided "
              "details.")
        print("\t\t3. get(model_id): Retrieves information about a specific model using its ID.")
        print("\t\t4. list(): Lists all models associated with the team and project.")
        print("\t\t5. delete(model_id): Deletes a model with the given ID.")
        print("\t\t6. clear_values(): Resets the team and project IDs to None.")
        print("\t\t7. validate(): Checks if the team and project IDs are of integer type.")
        print("\t\t8. help(): Displays this help message.")

        # Example usages
        print("\t\tExample usages:")
        print("\t\tmodels = Models(123, 456)")
        print("\t\tmodels.create('Model Name', 'Bucket Type', 'Bucket Name', 'Model Type')")
        print("\t\tmodels.get(789)")
        print("\t\tmodels.list()")
        print("\t\tmodels.delete(789)")



import json
from e2enetworks.cloud.aiplatform.init import init
from e2enetworks.cloud.aiplatform.Images import Images
from e2enetworks.cloud.aiplatform.Skus import Skus
from e2enetworks.cloud.aiplatform.Notebooks import Notebooks
from e2enetworks.cloud.aiplatform.Dataset import Datasets
from e2enetworks.cloud.aiplatform.EndPoint import EndPoints
from e2enetworks.cloud.aiplatform.Model import Models
from e2enetworks.cloud.aiplatform.Project import Projects
from e2enetworks.cloud.aiplatform.Teams import Teams
from e2enetworks.cloud.aiplatform.APIToken import APITokens


def help():
    print("\t\tAIPlatform Help")
    print("\t\t=================")
    print("\t\tAvailable classes:")
    print("\t\t- init: Provides functionalities for initialization.")
    print("\t\t- Images: Provides functionalities to interact with images.")
    print("\t\t- Skus: Provides functionalities to interact with skus.")
    print("\t\t- Notebooks: Provides functionalities to interact with notebooks.")
    print("\t\t- Datasets: Provides functionalities to interact with datasets.")
    print("\t\t- EndPoints: Provides functionalities to interact with endpoints.")
    print("\t\t- Models: Provides functionalities to interact with models.")
    print("\t\t- Projects: Provides functionalities to interact with projects.")
    print("\t\t- Teams: Provides functionalities to interact with teams.")
    print("\t\t- APITokens: Provides functionalities to interact with API tokens.")
    print("\t\t- beautify: beautify and print the specific response")

    # Call help() method on each class
    init.help()
    Images.help()
    Skus.help()
    Notebooks.help()
    Datasets.help()
    EndPoints.help()
    Models.help()
    Projects.help()
    Teams.help()
    APITokens.help()


def beautify(response):
    print(json.dumps(response.json(), indent=5))



import requests

from e2enetworks.cloud.aiplatform import config
from e2enetworks.cloud.aiplatform.constants import BASE_GPU_URL
from e2enetworks.cloud.aiplatform.decorators.validate_access_key_and_token import validate_access_key_and_token
from e2enetworks.cloud.aiplatform.constants import headers


class Images:

    @validate_access_key_and_token
    def list(self):
        url = f"{BASE_GPU_URL}gpu_service/image/?apikey={config.apikey}"
        payload = ""

        headers['Authorization'] = f'Bearer {config.auth_token}'

        response = requests.request("GET", url, headers=headers, data=payload)
        return response

    @staticmethod
    def help():
        print("Images Class Help")
        print("\t\t================")
        print("\t\tThis class provides functionalities to interact with Images.")
        print("\t\tAvailable methods:")

        print("\t\t1. list(): Lists all Images.")

        # Example usages
        print("\t\tExample usages:")
        print("\t\timages = Images()")
        print("\t\timages.list()")
